
-- CONFIGURATION ----------------------------------


local buffSize = 20				-- Size of buffs (default = 11)
local debuffSize = 1.5			-- Debuff size gets multiplied by this value. (default = 1)

local healthBarColor = { 0.15, 0.15, 0.15, 1 };	-- Health bar color values: { red, green, blue, alpha }.
local backgroundColor = { 1, 0.1, 0.1, 0.4 };	-- Background color values.

local centerName = true		-- Place names in the center of the frame? (default = false)


-- END OF CONFIG ----------------------------------




local function setupFrame(frame)
	local isPlayer = UnitIsPlayer(frame.unit)
	local _, raidClass = UnitClass(frame.unit)
	local raidClassColor = RAID_CLASS_COLORS[raidClass]
	local options = DefaultCompactUnitFrameSetupOptions
	local componentScale = min(options.height / 36, options.width / 72)


	-- Resize buffs
	frame.buffFrames[1]:SetSize(buffSize, buffSize)
	frame.buffFrames[2]:SetSize(buffSize, buffSize)
	frame.buffFrames[3]:SetSize(buffSize, buffSize)


	-- Resize debuffs
	frame.debuffFrames[1]:SetScale(debuffSize / componentScale)
	frame.debuffFrames[2]:SetScale(debuffSize / componentScale)
	frame.debuffFrames[3]:SetScale(debuffSize / componentScale)


	-- Reposition debuffs
	frame.debuffFrames[1]:ClearAllPoints()
	frame.debuffFrames[1]:SetPoint("TOPRIGHT", frame.background, -2, -2.5)
	frame.debuffFrames[2]:ClearAllPoints()
	frame.debuffFrames[2]:SetPoint("LEFT", frame.debuffFrames[1], -(debuffSize + 11 * componentScale), 0)
	frame.debuffFrames[3]:ClearAllPoints()
	frame.debuffFrames[3]:SetPoint("LEFT", frame.debuffFrames[2], -(debuffSize + 11 * componentScale), 0)


	-- Hide the "dispellable debuff" icons
	frame.dispelDebuffFrames[1]:SetAlpha(0)
	frame.dispelDebuffFrames[2]:SetAlpha(0)
	frame.dispelDebuffFrames[3]:SetAlpha(0)


	-- Recolor frames and names
	if not frame.optionTable.useClassColors then
		if (isPlayer == 1) and not (raidClassColor == nil) then
			frame.name:SetTextColor(raidClassColor.r, raidClassColor.g, raidClassColor.b)
		else
			frame.name:SetTextColor(0, 0.9, 0)
		end

		frame.healthBar:SetStatusBarColor(unpack(healthBarColor));
		frame.background:SetTexture(unpack(backgroundColor));
	end
end


local function setupName(frame)
	if centerName then
		frame.name:ClearAllPoints()
		frame.name:SetPoint("CENTER", frame.background, 0, 4)

		if (frame.name:GetText()) then
			frame.name:SetText(frame.name:GetText():sub(1,10))
		end
	end
end


hooksecurefunc("CompactUnitFrame_UpdateHealthColor", setupFrame)
hooksecurefunc("CompactUnitFrame_UpdateName", setupName)
